pub struct Notifications { /* private fields */ }Expand description
A registry of event subscribers.
Implementations
Sourceimpl Notifications
impl Notifications
pub fn new() -> Self
Sourcepub fn subscribe(
&mut self,
prefix: &str,
handler: impl Fn(&str, &str) + Send + Sync + 'static,
)
pub fn subscribe( &mut self, prefix: &str, handler: impl Fn(&str, &str) + Send + Sync + 'static, )
Subscribe to events whose name starts with prefix (e.g. "sql.").
Sourcepub fn instrument(&self, name: &str, payload: &str)
pub fn instrument(&self, name: &str, payload: &str)
Fire name with payload, invoking every subscriber whose prefix matches.